import {Component, Input} from '@angular/core'
import {Recipe} from '../../../shared/model/recipe.model'
import {SubscribingComponent} from '../../../shared/components/subscribing.component'
import {ActivatedRoute, Router} from '@angular/router'
import {Observable} from 'rxjs'
import {RecipeImageService} from '../../services/recipe-image.service'
import {environment} from '../../../../../environments/environment'
import {ErrorService} from '../../../shared/service/error.service'
import {globalLoadingWheel} from '../../../shared/components/loading-wheel/loading-wheel.component'

@Component({
  selector: 'cre-images-editor',
  templateUrl: './images-editor.component.html',
  styleUrls: ['./images-editor.component.sass']
})
export class ImagesEditorComponent extends SubscribingComponent {
  @Input() recipe: Recipe
  @Input() editionMode = false

  imageIds$: Observable<number[]>
  backendUrl = environment.apiUrl
  hasImages = false

  constructor(
    private recipeImageService: RecipeImageService,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit() {
    super.ngOnInit()

    this.loadImagesIds()
    this.subscribe(
      this.imageIds$,
      ids => this.hasImages = ids.length > 0,
      false,
      1
    )
  }

  submit(event) {
    const image = event.target.files[0]
    this.subscribe(
      this.recipeImageService.save(image, this.recipe.id),
      () => this.loadImagesIds()
    )
  }

  openImage(imageId: number) {
    window.open(`${environment.apiUrl}/recipe/${this.recipe.id}/image/${imageId}`, '_blank')
  }

  delete(imageId: number) {
    this.subscribe(
      this.recipeImageService.delete(imageId, this.recipe.id),
      () => this.loadImagesIds()
    )
  }

  private loadImagesIds() {
    this.imageIds$ = this.recipeImageService.getAllIdsForRecipe(this.recipe.id)
  }
}
